===============================================
Django Google API Python Client Storage Backend
===============================================

django-gapc-storage
-------------------

``django-gapc-storage`` is a Django storage backend for Google Cloud Storage
using the JSON API through google-api-python-client.


Requirements
--------------

* Django 1.8+
